Challenges In Computing
===============================

There are many challenges that real-world computing professionals have to deal with everyday. In this assignment, you will learn about a few obstacles and how people have tackled them.

Impostor Syndrome
------------------------------

Impostor syndrome is when competent individuals doubt their own abilities. In other words, it's when skilled people feel like frauds or impostors.

This obstacle is one of the most widespread issues in programming. Across age, experience level, and gender, almost everyone experiences impostor syndrome at some point in their career.

Many of the individuals interviewed for CSAwesome detail similar experiences. For example, :ref:`Camille-Mbayo` explains how it affected her journey:

    “People try to sound more knowledgeable than they are, and to someone who doesn’t know, that sounds like they know what they’re talking about. That definitely made me feel like I was behind. I never fully believed that I was a computer scientist until I had an internship.”

Luckily for Camille, her internship reaffirmed her value as a computer scientist. That doesn't work for everyone, though — especially professionals that are already in the field.

A more fullproof way of tackling impostor syndrome is to realize that working entails always learning. Everyone pretends like you either know computer science or you don't, but there's a lot of learning in the middle. The constant releases of new technology mean that everyone is constantly learning.

A Lack of Diversity
------------------------------

Computing has always suffered from a lack of diversity. Even though female professionals like Ada Lovelace (the first programmer) were crucial to the development of modern computers, the field is still male-dominated. Similarly, despite minority programmers like Marian Croak (the inventor of VoIP) and Guillermo Diaz Jr. (the CIO of Cisco for twenty years), many black, indigenous, and hispanic programmers feel isolated.

The problem is twofold: a lack of role models and a lack of peers.

A lack of role models that "look like them" deters many racial & gender minorities from entering computing. For example, as :ref:`Camille-Mbayo` explains:

    “Our computer science department had one woman teacher, and the whole engineering school only had one black women. And then she got pregnant and left for a while. The diversity was so small, so it was hard for me to find support.”

Having a role model shows students that the path they travel isn't impossible. It makes a career in computing seem more attainable and possible.

A lack of relatable peers can also lead to similar feelings of isolation. Students are often left out of study groups or social events, while professionals are excluded from after-work parties or passed over for promotions. As :ref:`Carla-De-Lira` explains:

    “Everyone had their own study group. All of the international students were very close knit. All of the domestic students, mostly white, were in their own group. And I'm like, 'I don't know. I guess I'm soloing this.'”

The solution to a lack of relatable peers is to seek out support groups or communities for your demographic. As :ref:`Briceida-Mariscal` explains:

    “One thing that I started doing was mentoring other Latinas. Helping them has made me feel like I'm being part of something bigger than myself. I'm not only paying it forward, but I'm also no longer feeling lonely.”
